@@ -48,31 +48,27 @@ namespace Oxygen
             BaseEngine( parent )
         {}
 
-        //* destructor
-        virtual ~WidgetStateEngine( void )
-        {}
-
         //* register widget
-        virtual bool registerWidget( QWidget*, AnimationModes );
+        bool registerWidget( QWidget*, AnimationModes );
 
         //* returns registered widgets
-        virtual WidgetList registeredWidgets( AnimationModes ) const;
+        WidgetList registeredWidgets( AnimationModes ) const;
 
         using BaseEngine::registeredWidgets;
 
         //* true if widget hover state is changed
-        virtual bool updateState( const QObject*, AnimationMode, bool );
+        bool updateState( const QObject*, AnimationMode, bool );
 
         //* true if widget is animated
-        virtual bool isAnimated( const QObject*, AnimationMode );
+        bool isAnimated( const QObject*, AnimationMode );
 
         //* animation opacity
-        virtual qreal opacity( const QObject* object, AnimationMode mode )
+        qreal opacity( const QObject* object, AnimationMode mode )
         { return isAnimated( object, mode ) ? data( object, mode ).data()->opacity(): AnimationData::OpacityInvalid; }
 
         //* animation mode
         /** precedence on focus */
-        virtual AnimationMode frameAnimationMode( const QObject* object )
+        AnimationMode frameAnimationMode( const QObject* object )
         {
             if( isAnimated( object, AnimationEnable ) ) return AnimationEnable;
             else if( isAnimated( object, AnimationFocus ) ) return AnimationFocus;
@@ -82,7 +78,7 @@ namespace Oxygen
 
         //* animation opacity
         /** precedence on focus */
-        virtual qreal frameOpacity( const QObject* object )
+        qreal frameOpacity( const QObject* object )
         {
             if( isAnimated( object, AnimationEnable ) ) return data( object, AnimationEnable ).data()->opacity();
             else if( isAnimated( object, AnimationFocus ) ) return data( object, AnimationFocus ).data()->opacity();
@@ -92,7 +88,7 @@ namespace Oxygen
 
         //* animation mode
         /** precedence on mouseOver */
-        virtual AnimationMode buttonAnimationMode( const QObject* object )
+        AnimationMode buttonAnimationMode( const QObject* object )
         {
             if( isAnimated( object, AnimationEnable ) ) return AnimationEnable;
             else if( isAnimated( object, AnimationHover ) ) return AnimationHover;
@@ -102,7 +98,7 @@ namespace Oxygen
 
         //* animation opacity
         /** precedence on mouseOver */
-        virtual qreal buttonOpacity( const QObject* object )
+        qreal buttonOpacity( const QObject* object )
         {
             if( isAnimated( object, AnimationEnable ) ) return data( object, AnimationEnable ).data()->opacity();
             else if( isAnimated( object, AnimationHover ) ) return data( object, AnimationHover ).data()->opacity();
@@ -111,7 +107,7 @@ namespace Oxygen
         }
 
         //* duration
-        void setEnabled( bool value )
+        void setEnabled( bool value ) override
         {
             BaseEngine::setEnabled( value );
             _hoverData.setEnabled( value );
@@ -120,7 +116,7 @@ namespace Oxygen
         }
 
         //* duration
-        void setDuration( int value )
+        void setDuration( int value ) override
         {
             BaseEngine::setDuration( value );
             _hoverData.setDuration( value );
@@ -131,7 +127,7 @@ namespace Oxygen
         public Q_SLOTS:
 
         //* remove widget from map
-        bool unregisterWidget( QObject* object )
+        bool unregisterWidget( QObject* object ) override
         {
             if( !object ) return false;
             bool found = false;
@@ -141,13 +137,11 @@ namespace Oxygen
             return found;
         }
 
-        protected:
+        private:
 
         //* returns data associated to widget
         DataMap<WidgetStateData>::Value data( const QObject*, AnimationMode );
 
-        private:
-
         //* maps
         DataMap<WidgetStateData> _hoverData;
         DataMap<WidgetStateData> _focusData;
